==> w1druppel-0.1.7.tgz: package/src-drupn/drupn-addon.h <==
#ifndef _DRUPN_ADDON_H_
#define _DRUPN_ADDON_H_
#include <js_native_api.h>

#define napi_call(env, call) do {                               \
  napi_status status = (call);                                  \
  if (status != napi_ok) {                                      \
    const napi_extended_error_info *error_info = NULL;          \
    napi_get_last_error_info((env), &error_info);               \
    bool is_pending;                                            \
    napi_is_exception_pending((env), &is_pending);              \
    if (!is_pending) {                                          \
      const char *message = (error_info->error_message == NULL) \
          ? "empty error message"                               \
          : error_info->error_message;                          \
      napi_throw_error((env), NULL, message);                   \
      return NULL;                                              \
    }                                                           \
  }                                                             \
} while (0);

#define string_length_latin1(env, nval, size_ptr) do {          \
  napi_call (env, napi_get_value_string_latin1 (env,            \
    nval, NULL, 0, size_ptr                                     \
  ))                                                            \
} while (0);

#define throw(env, fmt...) do {                                 \
  snprintf (err_str, err_str_size, fmt);                        \
  napi_throw_error (env, NULL, err_str);                        \
  return NULL;                                                  \
} while (0);

#define err_str_size 200

static char err_str[err_str_size];

static inline bool is_undefined (napi_env env, napi_value nval) {
  napi_valuetype result;
  napi_call (env, napi_typeof (env, nval, &result))
  return result == napi_undefined;
}

napi_value create_drupn_addon (const napi_env env);

#endif

==> w1druppel-0.2.3.tgz: package/src-drupn/drupn-addon.h <==
#ifndef _DRUPN_ADDON_H_
#define _DRUPN_ADDON_H_
#include <js_native_api.h>

// --- from node docs.
#define napi_call(env, call) do {                               \
  napi_status status = (call);                                  \
  if (status != napi_ok) {                                      \
    const napi_extended_error_info *error_info = NULL;          \
    napi_get_last_error_info((env), &error_info);               \
    bool is_pending;                                            \
    napi_is_exception_pending((env), &is_pending);              \
    if (!is_pending) {                                          \
      const char *message = (error_info->error_message == NULL) \
          ? "empty error message"                               \
          : error_info->error_message;                          \
      napi_throw_error((env), NULL, message);                   \
      return NULL;                                              \
    }                                                           \
  }                                                             \
} while (0);

#define string_length_latin1(env, nval, size_ptr) do {          \
  napi_call (env, napi_get_value_string_latin1 (env,            \
    nval, NULL, 0, size_ptr                                     \
  ))                                                            \
} while (0);

#define ERR_STR_SIZE 200

#define throw_rn(env, fmt...) do {                              \
  char err_str[ERR_STR_SIZE];                                   \
  snprintf (err_str, ERR_STR_SIZE, fmt);                        \
  napi_throw_error (env, NULL, err_str);                        \
  return NULL;                                                  \
} while (0);

#define throw_rf(env, fmt...) do {                              \
  char err_str[ERR_STR_SIZE];                                   \
  snprintf (err_str, ERR_STR_SIZE, fmt);                        \
  napi_throw_error (env, NULL, err_str);                        \
  return false;                                                 \
} while (0);

static inline bool is_undefined (napi_env env, napi_value nval) {
  napi_valuetype result;
  napi_call (env, napi_typeof (env, nval, &result))
  return result == napi_undefined;
}

napi_value create_drupn_addon (const napi_env env);

#endif
